@@ -60,7 +60,7 @@ import Data.Either (isRight)
 import Data.List
 import Data.List.Extra (groupSortOn, nubSort)
 import Data.Text (Text)
-import qualified Data.Text as T
+import Data.Text qualified as T
 import Data.Time.Calendar
 import Safe (headErr)
 import String.ANSI
@@ -213,7 +213,7 @@ commandsList progversion othercmds =
   -- it needs checking/updating after any wording/layout changes here
    "-------------------------------------------------------------------------------"
   ,progversion
-  ,"Usage: hledger COMMAND [OPTIONS] [-- ADDONOPTIONS]"
+  ,"Usage: hledger [COMMAND] [OPTIONS] [ARGS]"
   -- ,"Commands (builtins + addons):"  -- XXX adapt for commands --builtin
   ,"Commands:"
   ,""
